pypret.pnps module
==================

.. automodule:: pypret.pnps
    :no-members:
    
Public interface
----------------    
.. autofunction:: pypret.pnps.PNPS
.. autoclass:: pypret.pnps.FROG
.. autoclass:: pypret.pnps.IFROG
.. autoclass:: pypret.pnps.TDP
.. autoclass:: pypret.pnps.DSCAN
.. autoclass:: pypret.pnps.MIIPS

API
---
.. autoclass:: pypret.pnps.BasePNPS
.. autoclass:: pypret.pnps.CollinearPNPS
.. autoclass:: pypret.pnps.NoncollinearPNPS

